pub fn use_tiny_readback(layout: &ReadbackLayout, num_outputs: usize) -> boolExpand description
True when fused readback can use the tiny scalar fast path.
pub fn use_tiny_readback(layout: &ReadbackLayout, num_outputs: usize) -> boolTrue when fused readback can use the tiny scalar fast path.